QuicConnectError

Enum QuicConnectError 

pub enum QuicConnectError {
    EndpointStopping,
    CidsExhausted,
    InvalidServerName(String),
    InvalidRemoteAddress(SocketAddr),
    NoDefaultClientConfig,
    UnsupportedVersion,
}
noq_proto types that are used in the public iroh API. Errors in the parameters being used to create a new connection

These arise before any I/O has been performed.

Variants



EndpointStopping

The endpoint can no longer create new connections

Indicates that a necessary component of the endpoint has been dropped or otherwise disabled.



CidsExhausted

The connection could not be created because not enough of the CID space is available

Try using longer connection IDs



InvalidServerName(String)

The given server name was malformed



InvalidRemoteAddress(SocketAddr)

The remote SocketAddr supplied was malformed

Examples include attempting to connect to port 0, or using an inappropriate address family.



NoDefaultClientConfig

No default client configuration was set up

Use Endpoint::connect_with to specify a client configuration.



UnsupportedVersion

The local endpoint does not support the QUIC version specified in the client configuration