#[non_exhaustive]pub struct UdpStats {
pub datagrams: u64,
pub bytes: u64,
pub ios: u64,
}Expand description
noq_proto types that are used in the public iroh API.
Statistics about UDP datagrams transmitted or received on a connection
All QUIC packets are carried by UDP datagrams. Hence, these statistics cover all traffic on a connection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.datagrams: u64The amount of UDP datagrams observed
bytes: u64The total amount of bytes which have been transferred inside UDP datagrams
ios: u64The amount of I/O operations executed
Can be less than datagrams when GSO, GRO, and/or batched system calls are in use.