Struct VarInt
pub struct VarInt(/* private fields */);Expand description
noq types that are used in the public iroh API.
An integer less than 2^62
Values of this type are suitable for encoding as QUIC variable-length integer.
Implementations
impl VarInt
impl VarInt
pub const MAX_SIZE: usize = 8usize
Available on crate feature qlog only.
pub const MAX_SIZE: usize = 8usize
qlog only.The largest encoded value length
pub const fn from_u32(x: u32) -> VarInt
Available on crate feature qlog only.
pub const fn from_u32(x: u32) -> VarInt
qlog only.Construct a VarInt infallibly
pub fn from_u64(x: u64) -> Result<VarInt, VarIntBoundsExceeded>
Available on crate feature qlog only.
pub fn from_u64(x: u64) -> Result<VarInt, VarIntBoundsExceeded>
qlog only.Succeeds iff x < 2^62
pub const unsafe fn from_u64_unchecked(x: u64) -> VarInt
Available on crate feature qlog only.
pub const unsafe fn from_u64_unchecked(x: u64) -> VarInt
qlog only.pub const fn into_inner(self) -> u64
Available on crate feature qlog only.
pub const fn into_inner(self) -> u64
qlog only.Extract the integer value
pub fn saturating_add(self, rhs: impl Into<VarInt>) -> VarInt
Available on crate feature qlog only.
pub fn saturating_add(self, rhs: impl Into<VarInt>) -> VarInt
qlog only.Saturating integer addition. Computes self + rhs, saturating at the numeric bounds instead of overflowing.