pub struct AccessLimit<P: ProtocolHandler + Clone> { /* private fields */ }Expand description
Wraps an existing protocol, limiting its access, based on the provided function.
Any refused connection will be closed with an error code of 0 and reason not allowed.
Implementations
Sourceimpl<P: ProtocolHandler + Clone> AccessLimit<P>
impl<P: ProtocolHandler + Clone> AccessLimit<P>