pub struct Connecting { /* private fields */ }Expand description
An outgoing connection in progress.
This future resolves to a Connection once the handshake completes.
Implementations
Sourceimpl Connecting
impl Connecting
Sourcepub fn into_0rtt(self) -> Result<OutgoingZeroRttConnection, Connecting>
pub fn into_0rtt(self) -> Result<OutgoingZeroRttConnection, Connecting>
Converts this Connecting into a 0-RTT connection at the cost of weakened security.
If 0-RTT can be attempted, returns a OutgoingZeroRttConnection, which represents
outgoing 0-RTT connection.
If the 0-RTT cannot even be attempted, returns back the same Connecting without
changes. You can still .await this Connecting to get a normal Connection.
The OutgoingZeroRttConnection will attempt to resume a previous TLS session. However,
the remote endpoint may actually reject the 0-RTT data–yet still accept
the connection attempt in general, once the handshake has completed.
This possibility of whether the 0-RTT data was accepted or rejected is conveyed
through the ZeroRttStatus after calling OutgoingZeroRttConnection::handshake_completed.
When the handshake completes, it returns ZeroRttStatus::Accepted if the 0-RTT data
was accepted and ZeroRttStatus::Rejected if it was rejected. If it was rejected, the
existence of any streams opened and application data sent prior to the handshake
completing will not be conveyed to the remote application, and local operations on them
will return ZeroRttRejected errors.
A server may reject 0-RTT data at its discretion, but accepting 0-RTT data requires the relevant resumption state to be stored in the server, which servers may limit or lose for various reasons including not persisting resumption state across server restarts.
Security
This enables transmission of 0-RTT data, which is vulnerable to replay attacks, and should therefore never invoke non-idempotent operations.
You can use RecvStream::is_0rtt to check whether a stream has been opened in 0-RTT
and thus whether parts of the stream are operating under this reduced security level.
See also documentation for Accepting::into_0rtt.
Sourcepub async fn handshake_data(&mut self) -> Result<Box<dyn Any>, ConnectionError>
pub async fn handshake_data(&mut self) -> Result<Box<dyn Any>, ConnectionError>
Parameters negotiated during the handshake
Sourcepub async fn alpn(&mut self) -> Result<Vec<u8>, AlpnError>
pub async fn alpn(&mut self) -> Result<Vec<u8>, AlpnError>
Extracts the ALPN protocol from the peer’s handshake data.
Sourcepub fn remote_id(&self) -> EndpointId
pub fn remote_id(&self) -> EndpointId
Returns the EndpointId of the endpoint that this connection attempt tries to connect to.